@@ -1,4 +1,5 @@
 // SPDX-FileCopyrightText: 2021 Nheko Contributors
+// SPDX-FileCopyrightText: 2022 Nheko Contributors
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -10,16 +11,36 @@
 #include <QImage>
 #include <QThreadPool>
 
-class BlurhashResponse
-  : public QQuickImageResponse
+class BlurhashRunnable
+  : public QObject
   , public QRunnable
+{
+    Q_OBJECT
+public:
+    BlurhashRunnable(const QString &id, const QSize &requestedSize)
+      : m_id(id)
+      , m_requestedSize(requestedSize)
+    {}
+
+    void run() override;
+signals:
+    void done(QImage);
+    void error(QString);
+
+private:
+    QString m_id;
+    QSize m_requestedSize;
+};
+
+class BlurhashResponse : public QQuickImageResponse
 {
 public:
     BlurhashResponse(const QString &id, const QSize &requestedSize)
-      : m_id(id)
-      , m_requestedSize(requestedSize)
     {
-        setAutoDelete(false);
+        auto runnable = new BlurhashRunnable(id, requestedSize);
+        connect(runnable, &BlurhashRunnable::done, this, &BlurhashResponse::handleDone);
+        connect(runnable, &BlurhashRunnable::error, this, &BlurhashResponse::handleError);
+        QThreadPool::globalInstance()->start(runnable);
     }
 
     QQuickTextureFactory *textureFactory() const override
@@ -28,27 +49,34 @@ public:
     }
     QString errorString() const override { return m_error; }
 
-    void run() override;
+    void handleDone(QImage image)
+    {
+        m_image = std::move(image);
+        emit finished();
+    }
+    void handleError(QString error)
+    {
+        m_error = error;
+        emit finished();
+    }
 
-    QString m_id, m_error;
-    QSize m_requestedSize;
+    QString m_error;
     QImage m_image;
 };
 
 class BlurhashProvider
-  : public QObject
-  , public QQuickAsyncImageProvider
+  :
+#if QT_VERSION < 0x60000
+  public QObject
+  ,
+#endif
+  public QQuickAsyncImageProvider
 {
     Q_OBJECT
 public slots:
     QQuickImageResponse *
     requestImageResponse(const QString &id, const QSize &requestedSize) override
     {
-        BlurhashResponse *response = new BlurhashResponse(id, requestedSize);
-        pool.start(response);
-        return response;
+        return new BlurhashResponse(id, requestedSize);
     }
-
-private:
-    QThreadPool pool;
 };
