@@ -1,5 +1,6 @@
 // SPDX-FileCopyrightText: 2017 Konstantinos Sideris <siderisk@auth.gr>
 // SPDX-FileCopyrightText: 2021 Nheko Contributors
+// SPDX-FileCopyrightText: 2022 Nheko Contributors
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -38,10 +39,8 @@ QString
 avatarUrl(const QString &room_id, const QString &user_id);
 
 // presence
-mtx::presence::PresenceState
-presenceState(const std::string &user_id);
-std::string
-statusMessage(const std::string &user_id);
+mtx::events::presence::Presence
+presence(const std::string &user_id);
 
 // user cache stores user keys
 std::optional<UserKeyCache>
