@@ -6,7 +6,7 @@
 #pragma once
 
 #include <memory>
-#include <spdlog/spdlog.h>
+#include <spdlog/logger.h>
 
 namespace nhlog {
 void
