@@ -8,11 +8,13 @@
 
 #include <functional>
 
+#include <QHash>
 #include <QQuickView>
 #include <QSharedPointer>
 #include <QSystemTrayIcon>
 
 #include "UserSettingsPage.h"
+#include "dock/Dock.h"
 
 #include "jdenticoninterface.h"
 
@@ -47,8 +49,6 @@ public:
     static MainWindow *instance() { return instance_; }
     void saveCurrentWindowSize();
 
-    void
-    openCreateRoomDialog(std::function<void(const mtx::requests::CreateRoom &request)> callback);
     void openJoinRoomDialog(std::function<void(const QString &room_id)> callback);
 
     MxcImageProvider *imageProvider() { return imgProvider; }
@@ -56,6 +56,15 @@ public:
     //! Show the chat page and start communicating with the given access token.
     void showChatPage();
 
+#ifdef NHEKO_DBUS_SYS
+    bool dbusAvailable() const { return dbusAvailable_; }
+#endif
+
+    Q_INVOKABLE void addPerRoomWindow(const QString &room, QWindow *window);
+    Q_INVOKABLE void removePerRoomWindow(const QString &room, QWindow *window);
+    QWindow *windowForRoom(const QString &room);
+    QString focusedRoom() const;
+
 protected:
     void closeEvent(QCloseEvent *event);
     bool event(QEvent *event) override;
@@ -96,6 +105,13 @@ private:
     QSharedPointer<UserSettings> userSettings_;
     //! Tray icon that shows the unread message count.
     TrayIcon *trayIcon_;
+    Dock *dock_;
 
     MxcImageProvider *imgProvider = nullptr;
+
+    QMultiHash<QString, QWindow *> roomWindows_;
+
+#ifdef NHEKO_DBUS_SYS
+    bool dbusAvailable_{false};
+#endif
 };
