@@ -10,6 +10,7 @@
 #include <mtxclient/crypto/client.hpp>
 
 #include <QByteArray>
+#include <QCache>
 #include <QDir>
 #include <QFileInfo>
 #include <QPainter>
@@ -103,6 +104,18 @@ MxcImageProvider::download(const QString &id,
                            bool crop,
                            double radius)
 {
+    if (id.isEmpty()) {
+        nhlog::net()->warn("Attempted to download image with empty ID");
+        then(id, QSize{}, QImage{}, QString{});
+        return;
+    }
+
+    bool cropLocally = false;
+    if (crop && requestedSize.width() > 96) {
+        crop        = false;
+        cropLocally = true;
+    }
+
     std::optional<mtx::crypto::EncryptedFile> encryptionInfo;
     auto temp = infos.find("mxc://" + id);
     if (temp != infos.end())
@@ -119,7 +132,7 @@ MxcImageProvider::download(const QString &id,
                              .arg(requestedSize.width())
                              .arg(requestedSize.height())
                              .arg(crop ? "crop" : "scale")
-                             .arg(radius);
+                             .arg(cropLocally ? 0 : radius);
         QFileInfo fileInfo(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) +
                              "/media_cache",
                            fileName);
@@ -131,8 +144,16 @@ MxcImageProvider::download(const QString &id,
                 if (requestedSize.width() <= 0) {
                     image = image.scaledToHeight(requestedSize.height(), Qt::SmoothTransformation);
                 } else {
-                    image =
-                      image.scaled(requestedSize, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+                    image = image.scaled(requestedSize,
+                                         cropLocally ? Qt::KeepAspectRatioByExpanding
+                                                     : Qt::KeepAspectRatio,
+                                         Qt::SmoothTransformation);
+                    if (cropLocally) {
+                        image = image.copy((image.width() - requestedSize.width()) / 2,
+                                           (image.height() - requestedSize.height()) / 2,
+                                           requestedSize.width(),
+                                           requestedSize.height());
+                    }
                 }
 
                 if (radius != 0) {
@@ -153,8 +174,8 @@ MxcImageProvider::download(const QString &id,
         opts.method  = crop ? "crop" : "scale";
         http::client()->get_thumbnail(
           opts,
-          [fileInfo, requestedSize, radius, then, id, crop](const std::string &res,
-                                                            mtx::http::RequestErr err) {
+          [fileInfo, requestedSize, radius, then, id, crop, cropLocally](
+            const std::string &res, mtx::http::RequestErr err) {
               if (err || res.empty()) {
                   download(id, QSize(), then, crop, radius);
                   return;
@@ -167,8 +188,16 @@ MxcImageProvider::download(const QString &id,
                       image =
                         image.scaledToHeight(requestedSize.height(), Qt::SmoothTransformation);
                   } else {
-                      image =
-                        image.scaled(requestedSize, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+                      image = image.scaled(requestedSize,
+                                           cropLocally ? Qt::KeepAspectRatioByExpanding
+                                                       : Qt::KeepAspectRatio,
+                                           Qt::SmoothTransformation);
+                      if (cropLocally) {
+                          image = image.copy((image.width() - requestedSize.width()) / 2,
+                                             (image.height() - requestedSize.height()) / 2,
+                                             requestedSize.width(),
+                                             requestedSize.height());
+                      }
                   }
 
                   if (radius != 0) {
@@ -264,6 +293,7 @@ MxcImageProvider::download(const QString &id,
                       image.setText(QStringLiteral("original filename"),
                                     QString::fromStdString(originalFilename));
                       image.setText(QStringLiteral("mxc url"), "mxc://" + id);
+
                       then(id, requestedSize, image, fileInfo.absoluteFilePath());
                       return;
                   }
@@ -276,6 +306,7 @@ MxcImageProvider::download(const QString &id,
                   image.setText(QStringLiteral("original filename"),
                                 QString::fromStdString(originalFilename));
                   image.setText(QStringLiteral("mxc url"), "mxc://" + id);
+
                   then(id, requestedSize, image, fileInfo.absoluteFilePath());
               });
         } catch (std::exception &e) {
