@@ -18,6 +18,7 @@ class SingleImagePackModel : public QAbstractListModel
     Q_OBJECT
 
     Q_PROPERTY(QString roomid READ roomid CONSTANT)
+    Q_PROPERTY(bool fromSpace READ fromSpace CONSTANT)
     Q_PROPERTY(QString statekey READ statekey WRITE setStatekey NOTIFY statekeyChanged)
     Q_PROPERTY(QString attribution READ attribution WRITE setAttribution NOTIFY attributionChanged)
     Q_PROPERTY(QString packname READ packname WRITE setPackname NOTIFY packnameChanged)
@@ -47,6 +48,7 @@ public:
     bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
 
     QString roomid() const { return QString::fromStdString(roomid_); }
+    bool fromSpace() const { return fromSpace_; }
     QString statekey() const { return QString::fromStdString(statekey_); }
     QString packname() const { return QString::fromStdString(pack.pack->display_name); }
     QString attribution() const { return QString::fromStdString(pack.pack->attribution); }
@@ -91,4 +93,6 @@ private:
 
     mtx::events::msc2545::ImagePack pack;
     std::vector<std::string> shortcodes;
+
+    bool fromSpace_ = false;
 };
