@@ -1,5 +1,6 @@
 // SPDX-FileCopyrightText: 2017 Konstantinos Sideris <siderisk@auth.gr>
 // SPDX-FileCopyrightText: 2021 Nheko Contributors
+// SPDX-FileCopyrightText: 2022 Nheko Contributors
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -9,6 +10,7 @@
 #include <QMenu>
 #include <QPainter>
 #include <QTimer>
+#include <QWindow>
 
 #include "TrayIcon.h"
 
@@ -69,7 +71,10 @@ MsgCountComposedIcon::clone() const
 }
 
 QList<QSize>
-MsgCountComposedIcon::availableSizes(QIcon::Mode mode, QIcon::State state) const
+MsgCountComposedIcon::availableSizes(QIcon::Mode mode, QIcon::State state)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+  const
+#endif
 {
     Q_UNUSED(mode);
     Q_UNUSED(state);
@@ -96,7 +101,7 @@ MsgCountComposedIcon::pixmap(const QSize &size, QIcon::Mode mode, QIcon::State s
     return result;
 }
 
-TrayIcon::TrayIcon(const QString &filename, QWidget *parent)
+TrayIcon::TrayIcon(const QString &filename, QWindow *parent)
   : QSystemTrayIcon(parent)
 {
 #if defined(Q_OS_MAC) || defined(Q_OS_WIN)
@@ -106,13 +111,13 @@ TrayIcon::TrayIcon(const QString &filename, QWidget *parent)
     setIcon(QIcon(icon_));
 #endif
 
-    QMenu *menu = new QMenu(parent);
+    QMenu *menu = new QMenu();
     setContextMenu(menu);
 
     viewAction_ = new QAction(tr("Show"), this);
     quitAction_ = new QAction(tr("Quit"), this);
 
-    connect(viewAction_, SIGNAL(triggered()), parent, SLOT(show()));
+    connect(viewAction_, &QAction::triggered, parent, &QWindow::show);
     connect(quitAction_, &QAction::triggered, this, QApplication::quit);
 
     menu->addAction(viewAction_);
