@@ -11,7 +11,6 @@
 #include <QSettings>
 #include <QSharedPointer>
 
-#include "JdenticonProvider.h"
 #include <optional>
 
 class Toggle;
@@ -59,6 +58,8 @@ class UserSettings : public QObject
       bool avatarCircles READ avatarCircles WRITE setAvatarCircles NOTIFY avatarCirclesChanged)
     Q_PROPERTY(
       bool decryptSidebar READ decryptSidebar WRITE setDecryptSidebar NOTIFY decryptSidebarChanged)
+    Q_PROPERTY(bool spaceNotifications READ spaceNotifications WRITE setSpaceNotifications NOTIFY
+                 spaceNotificationsChanged)
     Q_PROPERTY(
       bool privacyScreen READ privacyScreen WRITE setPrivacyScreen NOTIFY privacyScreenChanged)
     Q_PROPERTY(int privacyScreenTimeout READ privacyScreenTimeout WRITE setPrivacyScreenTimeout
@@ -115,6 +116,8 @@ class UserSettings : public QObject
                  recentReactionsChanged)
     Q_PROPERTY(QStringList hiddenWidgets READ hiddenWidgets WRITE setHiddenWidgets NOTIFY
                  hiddenWidgetsChanged)
+    Q_PROPERTY(
+      bool exposeDBusApi READ exposeDBusApi WRITE setExposeDBusApi NOTIFY exposeDBusApiChanged)
 
     UserSettings();
 
@@ -161,6 +164,7 @@ public:
     void setAlertOnNotification(bool state);
     void setAvatarCircles(bool state);
     void setDecryptSidebar(bool state);
+    void setSpaceNotifications(bool state);
     void setPrivacyScreen(bool state);
     void setPrivacyScreenTimeout(int state);
     void setPresence(Presence state);
@@ -183,14 +187,16 @@ public:
     void setDeviceId(QString deviceId);
     void setHomeserver(QString homeserver);
     void setDisableCertificateValidation(bool disabled);
-    void setHiddenTags(QStringList hiddenTags);
-    void setHiddenPins(QStringList hiddenTags);
-    void setHiddenWidgets(QStringList hiddenTags);
+    void setHiddenTags(const QStringList &hiddenTags);
+    void setMutedTags(const QStringList &mutedTags);
+    void setHiddenPins(const QStringList &hiddenTags);
+    void setHiddenWidgets(const QStringList &hiddenTags);
     void setRecentReactions(QStringList recent);
     void setUseIdenticon(bool state);
     void setOpenImageExternal(bool state);
     void setOpenVideoExternal(bool state);
     void setCollapsedSpaces(QList<QStringList> spaces);
+    void setExposeDBusApi(bool state);
 
     QString theme() const { return !theme_.isEmpty() ? theme_ : defaultTheme_; }
     bool messageHoverHighlight() const { return messageHoverHighlight_; }
@@ -200,6 +206,7 @@ public:
     bool groupView() const { return groupView_; }
     bool avatarCircles() const { return avatarCircles_; }
     bool decryptSidebar() const { return decryptSidebar_; }
+    bool spaceNotifications() const { return spaceNotifications_; }
     bool privacyScreen() const { return privacyScreen_; }
     int privacyScreenTimeout() const { return privacyScreenTimeout_; }
     bool markdown() const { return markdown_; }
@@ -248,13 +255,15 @@ public:
     QString homeserver() const { return homeserver_; }
     bool disableCertificateValidation() const { return disableCertificateValidation_; }
     QStringList hiddenTags() const { return hiddenTags_; }
+    QStringList mutedTags() const { return mutedTags_; }
     QStringList hiddenPins() const { return hiddenPins_; }
     QStringList hiddenWidgets() const { return hiddenWidgets_; }
     QStringList recentReactions() const { return recentReactions_; }
-    bool useIdenticon() const { return useIdenticon_ && JdenticonProvider::isAvailable(); }
+    bool useIdenticon() const;
     bool openImageExternal() const { return openImageExternal_; }
     bool openVideoExternal() const { return openVideoExternal_; }
     QList<QStringList> collapsedSpaces() const { return collapsedSpaces_; }
+    bool exposeDBusApi() const { return exposeDBusApi_; }
 
 signals:
     void groupViewStateChanged(bool state);
@@ -275,6 +284,7 @@ signals:
     void alertOnNotificationChanged(bool state);
     void avatarCirclesChanged(bool state);
     void decryptSidebarChanged(bool state);
+    void spaceNotificationsChanged(bool state);
     void privacyScreenChanged(bool state);
     void privacyScreenTimeoutChanged(int state);
     void timelineMaxWidthChanged(int state);
@@ -310,6 +320,7 @@ signals:
     void hiddenPinsChanged();
     void hiddenWidgetsChanged();
     void recentReactionsChanged();
+    void exposeDBusApiChanged(bool state);
 
 private:
     // Default to system theme if QT_QPA_PLATFORMTHEME var is set.
@@ -336,6 +347,7 @@ private:
     bool hasAlertOnNotification_;
     bool avatarCircles_;
     bool decryptSidebar_;
+    bool spaceNotifications_;
     bool privacyScreen_;
     int privacyScreenTimeout_;
     bool shareKeysWithTrustedUsers_;
@@ -366,6 +378,7 @@ private:
     QString deviceId_;
     QString homeserver_;
     QStringList hiddenTags_;
+    QStringList mutedTags_;
     QStringList hiddenPins_;
     QStringList hiddenWidgets_;
     QStringList recentReactions_;
@@ -373,6 +386,7 @@ private:
     bool useIdenticon_;
     bool openImageExternal_;
     bool openVideoExternal_;
+    bool exposeDBusApi_;
 
     QSettings settings;
 
@@ -398,6 +412,9 @@ class UserSettingsModel : public QAbstractListModel
         UseIdenticon,
         PrivacyScreen,
         PrivacyScreenTimeout,
+#ifdef NHEKO_DBUS_SYS
+        ExposeDBusApi,
+#endif
 
         TimelineSection,
         TimelineMaxWidth,
@@ -416,6 +433,7 @@ class UserSettingsModel : public QAbstractListModel
         GroupView,
         SortByImportance,
         DecryptSidebar,
+        SpaceNotifications,
 
         TraySection,
         Tray,
@@ -457,6 +475,9 @@ class UserSettingsModel : public QAbstractListModel
         AccessToken,
 #ifdef Q_OS_MAC
         ScaleFactor,
+#endif
+#ifndef NHEKO_DBUS_SYS
+        ExposeDBusApi,
 #endif
     };
 
