@@ -7,10 +7,7 @@
 #pragma once
 
 #include <QObject>
-#include <QSet>
-#include <QString>
-#include <QVector>
-#include <vector>
+#include <array>
 
 namespace emoji {
 Q_NAMESPACE
@@ -35,11 +32,13 @@ public:
 
     Q_PROPERTY(const QString &unicode MEMBER unicode)
     Q_PROPERTY(const QString &shortName MEMBER shortName)
+    Q_PROPERTY(const QString &unicodeName MEMBER unicodeName)
     Q_PROPERTY(emoji::Emoji::Category category MEMBER category)
 
 public:
     QString unicode;
     QString shortName;
+    QString unicodeName;
     Category category;
 };
 
@@ -47,7 +46,7 @@ class Provider
 {
 public:
     // all emoji for QML purposes
-    static const QVector<Emoji> emoji;
+    static const std::array<Emoji, 3650> emoji;
 };
 
 } // namespace emoji
