@@ -7,12 +7,13 @@
 
 #include <QApplication>
 
+#include "Cache.h"
 #include "Cache_p.h"
 #include "ChatPage.h"
 #include "Logging.h"
-#include "MainWindow.h"
 #include "MatrixClient.h"
 #include "Olm.h"
+#include "encryption/VerificationManager.h"
 #include "timeline/TimelineViewManager.h"
 #include "ui/UIA.h"
 
@@ -150,7 +151,7 @@ SelfVerificationStatus::setupCrosssigning(bool useSSSS, QString password, bool u
                     olm::client()->identity_keys().ed25519 &&
                   myKey.keys["curve25519:" + http::client()->device_id()] ==
                     olm::client()->identity_keys().curve25519) {
-                  json j = myKey;
+                  nlohmann::json j = myKey;
                   j.erase("signatures");
                   j.erase("unsigned");
 
