@@ -1,5 +1,6 @@
 // SPDX-FileCopyrightText: 2017 Konstantinos Sideris <siderisk@auth.gr>
 // SPDX-FileCopyrightText: 2021 Nheko Contributors
+// SPDX-FileCopyrightText: 2022 Nheko Contributors
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -8,7 +9,6 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDesktopServices>
-#include <QDesktopWidget>
 #include <QDir>
 #include <QFile>
 #include <QFontDatabase>
@@ -17,6 +17,7 @@
 #include <QLibraryInfo>
 #include <QMessageBox>
 #include <QPoint>
+#include <QQuickView>
 #include <QScreen>
 #include <QStandardPaths>
 #include <QTranslator>
@@ -34,6 +35,11 @@
 #include "emoji/MacHelper.h"
 #endif
 
+#if defined(GSTREAMER_AVAILABLE) && (defined(Q_OS_MAC) || defined(Q_OS_WINDOWS))
+#include <QAbstractEventDispatcher>
+#include <gst/gst.h>
+#endif
+
 #ifdef QML_DEBUGGING
 #include <QQmlDebuggingEnabler>
 QQmlDebuggingEnabler enabler;
@@ -100,6 +106,23 @@ registerSignalHandlers()
 
 #endif
 
+#if defined(GSTREAMER_AVAILABLE) && (defined(Q_OS_MAC) || defined(Q_OS_WINDOWS))
+GMainLoop *gloop = 0;
+GThread *gthread = 0;
+
+extern "C"
+{
+    static gpointer glibMainLoopThreadFunc(gpointer)
+    {
+        gloop = g_main_loop_new(0, false);
+        g_main_loop_run(gloop);
+        g_main_loop_unref(gloop);
+        gloop = 0;
+        return 0;
+    }
+} // extern "C"
+#endif
+
 QPoint
 screenCenter(int width, int height)
 {
@@ -125,9 +148,9 @@ createStandardDirectory(QStandardPaths::StandardLocation path)
 int
 main(int argc, char *argv[])
 {
-    QCoreApplication::setApplicationName("nheko");
+    QCoreApplication::setApplicationName(QStringLiteral("nheko"));
     QCoreApplication::setApplicationVersion(nheko::version);
-    QCoreApplication::setOrganizationName("nheko");
+    QCoreApplication::setOrganizationName(QStringLiteral("nheko"));
     QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
@@ -145,24 +168,24 @@ main(int argc, char *argv[])
 
     // This is some hacky programming, but it's necessary (AFAIK?) to get the unique config name
     // parsed before the SingleApplication userdata is set.
-    QString userdata{""};
+    QString userdata{QLatin1String("")};
     QString matrixUri;
     for (int i = 1; i < argc; ++i) {
         QString arg{argv[i]};
-        if (arg.startsWith("--profile=")) {
-            arg.remove("--profile=");
+        if (arg.startsWith(QLatin1String("--profile="))) {
+            arg.remove(QStringLiteral("--profile="));
             userdata = arg;
-        } else if (arg.startsWith("--p=")) {
-            arg.remove("-p=");
+        } else if (arg.startsWith(QLatin1String("--p="))) {
+            arg.remove(QStringLiteral("-p="));
             userdata = arg;
-        } else if (arg == "--profile" || arg == "-p") {
+        } else if (arg == QLatin1String("--profile") || arg == QLatin1String("-p")) {
             if (i < argc - 1) // if i is less than argc - 1, we still have a parameter
                               // left to process as the name
             {
                 ++i; // the next arg is the name, so increment
                 userdata = QString{argv[i]};
             }
-        } else if (arg.startsWith("matrix:")) {
+        } else if (arg.startsWith(QLatin1String("matrix:"))) {
             matrixUri = arg;
         }
     }
@@ -174,20 +197,19 @@ main(int argc, char *argv[])
                             SingleApplication::Mode::ExcludeAppVersion |
                             SingleApplication::Mode::SecondaryNotification,
                           100,
-                          userdata == "default" ? "" : userdata);
+                          userdata == QLatin1String("default") ? QLatin1String("") : userdata);
 
     QCommandLineParser parser;
     parser.addHelpOption();
     parser.addVersionOption();
-    QCommandLineOption debugOption("debug", "Enable debug output");
+    QCommandLineOption debugOption(QStringLiteral("debug"), QStringLiteral("Enable debug output"));
     parser.addOption(debugOption);
 
     // This option is not actually parsed via Qt due to the need to parse it before the app
     // name is set. It only exists to keep Qt from complaining about the --profile/-p
     // option and thereby crashing the app.
     QCommandLineOption configName(
-      QStringList() << "p"
-                    << "profile",
+      QStringList() << QStringLiteral("p") << QStringLiteral("profile"),
       QCoreApplication::tr("Create a unique profile, which allows you to log into several "
                            "accounts at the same time and start multiple instances of nheko."),
       QCoreApplication::tr("profile"),
@@ -207,12 +229,13 @@ main(int argc, char *argv[])
     }
 
 #if !defined(Q_OS_MAC)
-    app.setWindowIcon(QIcon::fromTheme("nheko", QIcon{":/logos/nheko.png"}));
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("nheko"), QIcon{":/logos/nheko.png"}));
+#endif
+#ifdef NHEKO_FLATPAK
+    app.setDesktopFileName(QStringLiteral("io.github.NhekoReborn.Nheko"));
+#else
+    app.setDesktopFileName(QStringLiteral("nheko"));
 #endif
-    if (userdata.isEmpty() || userdata == "default")
-        app.setDesktopFileName("nheko");
-    else
-        app.setDesktopFileName("nheko[" + userdata + "]");
 
     http::init();
 
@@ -221,11 +244,21 @@ main(int argc, char *argv[])
 
     registerSignalHandlers();
 
+#if defined(GSTREAMER_AVAILABLE) && (defined(Q_OS_MAC) || defined(Q_OS_WINDOWS))
+    // If the version of Qt we're running in does not use GLib, we need to
+    // start a GMainLoop so that gstreamer can dispatch events.
+    const QMetaObject *mo = QAbstractEventDispatcher::instance(qApp->thread())->metaObject();
+    if (gloop == 0 && strcmp(mo->className(), "QEventDispatcherGlib") != 0 &&
+        strcmp(mo->superClass()->className(), "QEventDispatcherGlib") != 0) {
+        gthread = g_thread_new(0, glibMainLoopThreadFunc, 0);
+    }
+#endif
+
     if (parser.isSet(debugOption))
         nhlog::enable_debug_log_from_commandline = true;
 
     try {
-        nhlog::init(QString("%1/nheko.log")
+        nhlog::init(QStringLiteral("%1/nheko.log")
                       .arg(QStandardPaths::writableLocation(QStandardPaths::CacheLocation))
                       .toStdString());
     } catch (const spdlog::spdlog_ex &ex) {
@@ -242,28 +275,34 @@ main(int argc, char *argv[])
 
     QFont font;
     QString userFontFamily = settings.lock()->font();
-    if (!userFontFamily.isEmpty() && userFontFamily != "default") {
+    if (!userFontFamily.isEmpty() && userFontFamily != QLatin1String("default")) {
         font.setFamily(userFontFamily);
     }
     font.setPointSizeF(settings.lock()->fontSize());
 
     app.setFont(font);
+    settings.lock()->applyTheme();
 
     if (QLocale().language() == QLocale::C)
         QLocale::setDefault(QLocale(QLocale::English, QLocale::UnitedKingdom));
 
     QTranslator qtTranslator;
-    qtTranslator.load(QLocale(), "qt", "_", QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+    qtTranslator.load(QLocale(),
+                      QStringLiteral("qt"),
+                      QStringLiteral("_"),
+                      QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     app.installTranslator(&qtTranslator);
 
     QTranslator appTranslator;
-    appTranslator.load(QLocale(), "nheko", "_", ":/translations");
+    appTranslator.load(
+      QLocale(), QStringLiteral("nheko"), QStringLiteral("_"), QStringLiteral(":/translations"));
     app.installTranslator(&appTranslator);
 
     MainWindow w;
+    // QQuickView w;
 
     // Move the MainWindow to the center
-    w.move(screenCenter(w.width(), w.height()));
+    // w.move(screenCenter(w.width(), w.height()));
 
     if (!(settings.lock()->startInTray() && settings.lock()->tray()))
         w.show();
@@ -279,7 +318,7 @@ main(int argc, char *argv[])
     QObject::connect(&app, &SingleApplication::instanceStarted, &w, [&w]() {
         w.show();
         w.raise();
-        w.activateWindow();
+        w.requestActivate();
     });
 
     // It seems like handling the message in a blocking manner is a no-go. I have no idea how to
@@ -305,7 +344,8 @@ main(int argc, char *argv[])
                                              QObject::disconnect(uriConnection);
                                          });
     }
-    QDesktopServices::setUrlHandler("matrix", ChatPage::instance(), "handleMatrixUri");
+    QDesktopServices::setUrlHandler(
+      QStringLiteral("matrix"), ChatPage::instance(), "handleMatrixUri");
 
 #if defined(Q_OS_MAC)
     // Temporary solution for the emoji picker until
