@@ -11,11 +11,6 @@
 
 #include <mtx/responses/notifications.hpp>
 
-// convenience definition
-#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD) || defined(Q_OS_HAIKU)
-#define NHEKO_DBUS_SYS
-#endif
-
 #if defined(NHEKO_DBUS_SYS)
 #include <QtDBus/QDBusArgument>
 #include <QtDBus/QDBusInterface>
