@@ -8,6 +8,7 @@
 #include <CacheStructs.h>
 #include <QAbstractListModel>
 #include <QHash>
+#include <QQmlEngine>
 #include <QSharedPointer>
 #include <QSortFilterProxyModel>
 #include <QString>
@@ -17,6 +18,10 @@
 
 #include "TimelineModel.h"
 
+#ifdef NHEKO_DBUS_SYS
+#include "dbus/NhekoDBusBackend.h"
+#endif
+
 class TimelineViewManager;
 
 class RoomPreview
@@ -85,6 +90,7 @@ public:
         else
             return {};
     }
+    RoomPreview getRoomPreviewById(QString roomid) const;
 
 public slots:
     void initializeRooms();
@@ -99,10 +105,10 @@ public slots:
 
         return -1;
     }
-    void joinPreview(QString roomid, QString parentSpace);
+    void joinPreview(QString roomid);
     void acceptInvite(QString roomid);
     void declineInvite(QString roomid);
-    void leave(QString roomid);
+    void leave(QString roomid, QString reason = "");
     TimelineModel *currentRoom() const { return currentRoom_.get(); }
     RoomPreview currentRoomPreview() const { return currentRoomPreview_.value_or(RoomPreview{}); }
     void setCurrentRoom(QString roomid);
@@ -138,6 +144,11 @@ private:
 
     std::map<QString, std::vector<QString>> directChatToUser;
 
+#ifdef NHEKO_DBUS_SYS
+    NhekoDBusBackend *dbusInterface_;
+    friend class NhekoDBusBackend;
+#endif
+
     friend class FilteredRoomlistModel;
 };
 
@@ -158,15 +169,12 @@ public slots:
     {
         return mapFromSource(roomlistmodel->index(roomlistmodel->roomidToIndex(roomid))).row();
     }
-    void joinPreview(QString roomid)
-    {
-        roomlistmodel->joinPreview(roomid,
-                                   filterType == FilterBy::Space ? filterStr : QLatin1String(""));
-    }
+    void joinPreview(QString roomid) { roomlistmodel->joinPreview(roomid); }
     void acceptInvite(QString roomid) { roomlistmodel->acceptInvite(roomid); }
     void declineInvite(QString roomid) { roomlistmodel->declineInvite(roomid); }
-    void leave(QString roomid) { roomlistmodel->leave(roomid); }
+    void leave(QString roomid, QString reason = "") { roomlistmodel->leave(roomid, reason); }
     void toggleTag(QString roomid, QString tag, bool on);
+    void copyLink(QString roomid);
 
     TimelineModel *currentRoom() const { return roomlistmodel->currentRoom(); }
     RoomPreview currentRoomPreview() const { return roomlistmodel->currentRoomPreview(); }
@@ -174,7 +182,13 @@ public slots:
     void resetCurrentRoom() { roomlistmodel->resetCurrentRoom(); }
     TimelineModel *getRoomById(const QString &id) const
     {
-        return roomlistmodel->getRoomById(id).data();
+        auto r = roomlistmodel->getRoomById(id).data();
+        QQmlEngine::setObjectOwnership(r, QQmlEngine::CppOwnership);
+        return r;
+    }
+    RoomPreview getRoomPreviewById(QString roomid) const
+    {
+        return roomlistmodel->getRoomPreviewById(roomid);
     }
 
     void nextRoomWithActivity();
