@@ -22,8 +22,11 @@
 #include "RoomsModel.h"
 #include "UserSettingsPage.h"
 #include "UsersModel.h"
+#include "Utils.h"
 #include "emoji/EmojiModel.h"
-#include "emoji/Provider.h"
+#include "encryption/VerificationManager.h"
+#include "voip/CallManager.h"
+#include "voip/WebRTCSession.h"
 
 namespace msgs = mtx::events::msg;
 
@@ -138,10 +141,6 @@ TimelineViewManager::TimelineViewManager(CallManager *, ChatPage *parent)
         isInitialSync_ = true;
         emit initialSyncChanged(true);
     });
-    connect(qobject_cast<QApplication *>(QApplication::instance()),
-            &QApplication::focusWindowChanged,
-            this,
-            &TimelineViewManager::focusChanged);
     connect(parent, &ChatPage::connectionLost, this, [this] {
         isConnected_ = false;
         emit isConnectedChanged(false);
@@ -152,12 +151,6 @@ TimelineViewManager::TimelineViewManager(CallManager *, ChatPage *parent)
     });
 }
 
-bool
-TimelineViewManager::isWindowFocused() const
-{
-    return MainWindow::instance() == QApplication::focusWindow();
-}
-
 void
 TimelineViewManager::openRoomMembers(TimelineModel *room)
 {
@@ -199,6 +192,14 @@ TimelineViewManager::openGlobalUserProfile(QString userId)
     emit openProfile(profile);
 }
 
+UserProfile *
+TimelineViewManager::getGlobalUserProfile(QString userId)
+{
+    UserProfile *profile = new UserProfile{QString{}, userId, this};
+    QQmlEngine::setObjectOwnership(profile, QQmlEngine::JavaScriptOwnership);
+    return (profile);
+}
+
 void
 TimelineViewManager::setVideoCallItem()
 {
@@ -224,7 +225,10 @@ void
 TimelineViewManager::showEvent(const QString &room_id, const QString &event_id)
 {
     if (auto room = rooms_->getRoomById(room_id)) {
-        if (rooms_->currentRoom() != room) {
+        auto exWin = MainWindow::instance()->windowForRoom(room_id);
+        if (exWin) {
+            exWin->requestActivate();
+        } else if (rooms_->currentRoom() != room) {
             rooms_->setCurrentRoom(room_id);
             MainWindow::instance()->requestActivate();
             nhlog::ui()->info("Activated room {}", room_id.toStdString());
@@ -241,13 +245,17 @@ TimelineViewManager::escapeEmoji(QString str) const
 }
 
 void
-TimelineViewManager::openImageOverlay(TimelineModel *room, QString mxcUrl, QString eventId)
+TimelineViewManager::openImageOverlay(TimelineModel *room,
+                                      QString mxcUrl,
+                                      QString eventId,
+                                      double originalWidth,
+                                      double proportionalHeight)
 {
     if (mxcUrl.isEmpty()) {
         return;
     }
 
-    emit showImageOverlay(room, eventId, mxcUrl);
+    emit showImageOverlay(room, eventId, mxcUrl, originalWidth, proportionalHeight);
 }
 
 void
@@ -339,7 +347,7 @@ TimelineViewManager::queueReply(const QString &roomid,
 
 void
 TimelineViewManager::queueCallMessage(const QString &roomid,
-                                      const mtx::events::msg::CallInvite &callInvite)
+                                      const mtx::events::voip::CallInvite &callInvite)
 {
     if (auto room = rooms_->getRoomById(roomid))
         room->sendMessageEvent(callInvite, mtx::events::EventType::CallInvite);
@@ -347,7 +355,7 @@ TimelineViewManager::queueCallMessage(const QString &roomid,
 
 void
 TimelineViewManager::queueCallMessage(const QString &roomid,
-                                      const mtx::events::msg::CallCandidates &callCandidates)
+                                      const mtx::events::voip::CallCandidates &callCandidates)
 {
     if (auto room = rooms_->getRoomById(roomid))
         room->sendMessageEvent(callCandidates, mtx::events::EventType::CallCandidates);
@@ -355,7 +363,7 @@ TimelineViewManager::queueCallMessage(const QString &roomid,
 
 void
 TimelineViewManager::queueCallMessage(const QString &roomid,
-                                      const mtx::events::msg::CallAnswer &callAnswer)
+                                      const mtx::events::voip::CallAnswer &callAnswer)
 {
     if (auto room = rooms_->getRoomById(roomid))
         room->sendMessageEvent(callAnswer, mtx::events::EventType::CallAnswer);
@@ -363,7 +371,7 @@ TimelineViewManager::queueCallMessage(const QString &roomid,
 
 void
 TimelineViewManager::queueCallMessage(const QString &roomid,
-                                      const mtx::events::msg::CallHangUp &callHangUp)
+                                      const mtx::events::voip::CallHangUp &callHangUp)
 {
     if (auto room = rooms_->getRoomById(roomid))
         room->sendMessageEvent(callHangUp, mtx::events::EventType::CallHangUp);
