@@ -12,21 +12,13 @@
 
 #include <mtx/common.hpp>
 #include <mtx/responses/messages.hpp>
-#include <mtx/responses/sync.hpp>
 
-#include "Cache.h"
-#include "JdenticonProvider.h"
-#include "Logging.h"
-#include "TimelineModel.h"
-#include "Utils.h"
-#include "emoji/EmojiModel.h"
-#include "emoji/Provider.h"
-#include "encryption/VerificationManager.h"
+#include "ReadReceiptsModel.h"
 #include "timeline/CommunitiesModel.h"
 #include "timeline/PresenceEmitter.h"
 #include "timeline/RoomlistModel.h"
-#include "voip/CallManager.h"
-#include "voip/WebRTCSession.h"
+#include "ui/RoomSettings.h"
+#include "ui/UserProfile.h"
 
 class MxcImageProvider;
 class BlurhashProvider;
@@ -34,6 +26,13 @@ class ColorImageProvider;
 class UserSettings;
 class ChatPage;
 class ImagePackListModel;
+class TimelineModel;
+class CallManager;
+class VerificationManager;
+
+namespace mtx::responses {
+struct Sync;
+}
 
 class TimelineViewManager : public QObject
 {
@@ -41,7 +40,6 @@ class TimelineViewManager : public QObject
 
     Q_PROPERTY(
       bool isInitialSync MEMBER isInitialSync_ READ isInitialSync NOTIFY initialSyncChanged)
-    Q_PROPERTY(bool isWindowFocused READ isWindowFocused NOTIFY focusChanged)
     Q_PROPERTY(bool isConnected READ isConnected NOTIFY isConnectedChanged)
 
 public:
@@ -54,9 +52,12 @@ public:
     void clearAll() { rooms_->clear(); }
 
     Q_INVOKABLE bool isInitialSync() const { return isInitialSync_; }
-    bool isWindowFocused() const;
     bool isConnected() const { return isConnected_; }
-    Q_INVOKABLE void openImageOverlay(TimelineModel *room, QString mxcUrl, QString eventId);
+    Q_INVOKABLE void openImageOverlay(TimelineModel *room,
+                                      QString mxcUrl,
+                                      QString eventId,
+                                      double originalWidth,
+                                      double proportionalHeight);
     Q_INVOKABLE void openImagePackSettings(QString roomid);
     Q_INVOKABLE void saveMedia(QString mxcUrl);
     Q_INVOKABLE QColor userColor(QString id, QColor background);
@@ -67,6 +68,7 @@ public:
     Q_INVOKABLE void openRoomSettings(QString room_id);
     Q_INVOKABLE void openInviteUsers(QString roomId);
     Q_INVOKABLE void openGlobalUserProfile(QString userId);
+    Q_INVOKABLE UserProfile *getGlobalUserProfile(QString userId);
 
     Q_INVOKABLE void focusMessageInput();
 
@@ -81,15 +83,18 @@ signals:
     void inviteUsers(QString roomId, QStringList users);
     void showRoomList();
     void narrowViewChanged();
-    void focusChanged();
     void focusInput();
     void openRoomMembersDialog(MemberList *members, TimelineModel *room);
     void openRoomSettingsDialog(RoomSettings *settings);
     void openInviteUsersDialog(InviteesModel *invitees);
     void openProfile(UserProfile *profile);
     void showImagePackSettings(TimelineModel *room, ImagePackListModel *packlist);
-    void openLeaveRoomDialog(QString roomid);
-    void showImageOverlay(TimelineModel *room, QString eventId, QString url);
+    void openLeaveRoomDialog(QString roomid, QString reason = "");
+    void showImageOverlay(TimelineModel *room,
+                          QString eventId,
+                          QString url,
+                          double originalWidth,
+                          double proportionalHeight);
 
 public slots:
     void updateReadReceipts(const QString &room_id, const std::vector<QString> &event_ids);
@@ -100,10 +105,10 @@ public slots:
 
     void updateColorPalette();
     void queueReply(const QString &roomid, const QString &repliedToEvent, const QString &replyBody);
-    void queueCallMessage(const QString &roomid, const mtx::events::msg::CallInvite &);
-    void queueCallMessage(const QString &roomid, const mtx::events::msg::CallCandidates &);
-    void queueCallMessage(const QString &roomid, const mtx::events::msg::CallAnswer &);
-    void queueCallMessage(const QString &roomid, const mtx::events::msg::CallHangUp &);
+    void queueCallMessage(const QString &roomid, const mtx::events::voip::CallInvite &);
+    void queueCallMessage(const QString &roomid, const mtx::events::voip::CallCandidates &);
+    void queueCallMessage(const QString &roomid, const mtx::events::voip::CallAnswer &);
+    void queueCallMessage(const QString &roomid, const mtx::events::voip::CallHangUp &);
 
     void setVideoCallItem();
 
