@@ -22,6 +22,7 @@ Nheko::Nheko()
     connect(
       UserSettings::instance().get(), &UserSettings::themeChanged, this, &Nheko::colorsChanged);
     connect(ChatPage::instance(), &ChatPage::contentLoaded, this, &Nheko::updateUserProfile);
+    connect(ChatPage::instance(), &ChatPage::showRoomJoinPrompt, this, &Nheko::showRoomJoinPrompt);
     connect(this, &Nheko::joinRoom, ChatPage::instance(), &ChatPage::joinRoom);
 }
 
@@ -128,10 +129,29 @@ Nheko::logout() const
 }
 
 void
-Nheko::createRoom(QString name, QString topic, QString aliasLocalpart, bool isEncrypted, int preset)
+Nheko::setTransientParent(QWindow *window, QWindow *parentWindow) const
+{
+    if (window)
+        window->setTransientParent(parentWindow);
+}
+
+void
+Nheko::createRoom(bool space,
+                  QString name,
+                  QString topic,
+                  QString aliasLocalpart,
+                  bool isEncrypted,
+                  int preset)
 {
     mtx::requests::CreateRoom req;
 
+    if (space) {
+        req.creation_content       = mtx::events::state::Create{};
+        req.creation_content->type = mtx::events::state::room_type::space;
+        req.creation_content->creator.clear();
+        req.creation_content->room_version.clear();
+    }
+
     switch (preset) {
     case 1:
         req.preset = mtx::requests::Preset::PublicChat;
